<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="state.title"
        width="550px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="superRef" :rules="state.formRules" label-width="180px" >
        <el-form-item label="企业名称:"  prop="companyName" >
          <el-select
              v-if="state.isAdmin"
              v-model="state.form.companyName"
              style="width: 100%"
              v-loadMoreNew:[reselect]="handleScroll"
              :popper-class="reselect.name"
              @change="selectCompany"
              class="item-width"
          >
            <el-option
                v-for="item in state.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.name"
            />
          </el-select>

          <el-input v-else v-model.trim="state.form.companyName" disabled ></el-input>
        </el-form-item>
        <el-form-item label="计划名称:"  prop="planName" >
          <el-input v-model.trim="state.form.planName" placeholder="请输入计划名称"></el-input>
        </el-form-item>
        <el-form-item label="学员:"  prop="studentName" >
          <el-select
              v-model="state.form.studentName"
              style="width: 100%"
              v-loadMoreNew:[reselectStu]="handleScrollStu"
              :popper-class="reselectStu.name"
              class="m-2"
              @change="selectValue"
              placeholder="请选择学生"
              popper-class="more_select_dropdown"
          >
            <el-option
                v-for="item in state.studentList"
                :key="item.id"
                :label="item.name"
                :value="item.name"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="课程名称:"  prop="courseName" >
          <el-input v-model.trim="state.form.courseName" :disabled="disabled" placeholder="请输入课程名称" ></el-input>
        </el-form-item>
        <el-form-item label="培训等级:"  prop="level" >
          <el-select
              v-model="state.form.level"
              style="width: 100%"
          >
            <el-option
                v-for="item in state.levelList"
                :key="item.id"
                :label="item.name"
                :value="item.id"
            />
          </el-select>
<!--          <el-input v-model.trim="state.form.level" :disabled="disabled" placeholder="请输入培训等级" ></el-input>-->
        </el-form-item>
        <el-form-item label="要求课时（分）:"  prop="period" >
          <el-input v-model.trim="state.form.period"
                    @input="state.form.period = state.form.period
                    .replace(/[^0-9.]/g, '')
                    .replace(/(\..*)\./g, '$1')
                    .replace(/^(-?\d+\.?\d*).*/, '$1')"
                    :disabled="disabled" placeholder="请输入要求课时（分）" ></el-input>
        </el-form-item>
        <el-form-item label="实际课时（分）:"  prop="actualPeriod" >
          <el-input v-model.trim="state.form.actualPeriod"
                    @input="state.form.actualPeriod = state.form.actualPeriod
                    .replace(/[^0-9.]/g, '')
                    .replace(/(\..*)\./g, '$1')
                    .replace(/^(-?\d+\.?\d*).*/, '$1')"
                    :disabled="disabled" placeholder="请输入实际课时（分）" ></el-input>
        </el-form-item>
        <el-form-item label="考试成绩:"  prop="score" >
          <el-input v-model.trim="state.form.score"
                    @input="state.form.score = state.form.score
                    .replace(/[^0-9.]/g, '')
                    .replace(/(\..*)\./g, '$1')
                    .replace(/^(-?\d+\.?\d*).*/, '$1')"
                    :disabled="disabled" placeholder="请输入考试成绩" ></el-input>
        </el-form-item>
        <el-form-item label="是否合格:"  prop="passed" >
          <el-radio-group v-model="state.form.passed"  :disabled="disabled">
            <el-radio :label="0">不合格</el-radio>
            <el-radio :label="1">合格</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="培训记录:"  prop="passed" >
          <el-upload accept=".jpg,.jpeg,.png,.doc,.docx,.pdf,.xls,xlsx,ppt,pptx" style="width: 100%" :action="state.uploadUrl" :headers="state.header" method="post" :on-success="(res, uploadFile)=>handleAvatarSuccess(res, uploadFile)" :on-exceed="showTip"  v-model:file-list="state.fileList" :before-upload="picSize" :on-remove="(file, uploadFiles)=>handleRemove(file, uploadFiles)" >
            <el-button type="primary">点击上传</el-button>
<!--            <template #tip>-->
<!--              <div class="el-upload__tip">尺寸小于5M，最多可上传1份</div>-->
<!--            </template>-->
          </el-upload>
        </el-form-item>
      </el-form>
      <template #footer v-if="state.title !='查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs, defineEmits, nextTick, onMounted} from 'vue'
import { View } from "@element-plus/icons-vue";
import scorllSelect from '@/components/scrollSelect/index.vue'
import {ElMessage, ElMessageBox} from "element-plus";
import {verifyPhone, verifyPwd, verifyUsername} from "@/utils/validate";
import { checkUserName, checkPhone } from "@/api/login"
import {getStudent, resetPwd} from "@/api/onlineEducation/student"
import {Base64} from "js-base64"
import Cookies from "js-cookie";
import {addStudent, checkStuIdNo, checkStuPhone, editStudent} from "@/api/onlineEducation/student";
import {addRecord, editRecord} from "@/api/onlineEducation/examRecord";
import {getCompany} from "@/api/onlineEducation/company";
import {delPic} from "@/api/onlineEducation/banner";
import {getToken} from "@/utils/auth";

const emit = defineEmits(["getList"]);
const dialogVisible = ref(false)
const superRef = ref(null)
const scrollRef = ref(null)
const reselect = reactive({
  name: 'company'
})
const reselectStu = reactive({
  name: 'student'
})

const state = reactive({
  title: '',
  form: {
    id: null,
    companyName: '',
    planName: '',
    studentId: '',
    level: '',
    period: '',
    actualPeriod: '',
    score: null,
    passed: 0,
    studentName: '',
    courseName: '',
    companyId: null,
    files: []

  },
  formRules:{
    companyName: [{ required: true, message: '请输入企业名称', trigger: 'blur' }],
    planName: [{ required: true, message: '请输入计划名称', trigger: 'blur' }],
    studentName: [{ required: true, message: '请选择学员', trigger: 'blur' }],
    level: [{ required: true, message: '请输入培训等级', trigger: 'blur' }],
    period: [{ required: true, message: '请输入要求课时（分）', trigger: 'blur' }],
    actualPeriod: [{ required: true, message: '实际课时（分）', trigger: 'blur' }],
    score: [{ required: true, message: '请输入考试成绩', trigger: 'blur' }],
  },
  isAdmin: false,
  studentList: [],
  stuPageNum: 1, // 当前页码
  stuPageSize: 10, // 每页显示的数量
  hasMoreStu: null, // 是否还有更多选项
  pageNum: 1,
  pageSize: 10,
  companyList: [],
  companyPageNum: 1, // 当前页码
  companyPageSize: 10, // 每页显示的数量
  hasMoreItems: null, // 是否还有更多选项
  levelList: [
    {
      id: 1,
      name: '公司级'
    },
    {
      id: 2,
      name: '部门级'
    },
  ],
  uploadUrl: import.meta.env.VITE_APP_BASE_API + '/system/common/uploadFile',
  header: {
    Authorization: getToken()
  },

})
onMounted(() => {

});

const disabled = ref(false);
const openDialog = async (type, value) => {
  await loadMoreStuData();
  if(state.isAdmin){
    await loadMoreCompanyData();
  }
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  console.log("userInfo",userInfo)
  if(userInfo.userType === 0){
    state.isAdmin = true;
    state.form.userType = 0;
  }else {
    state.isAdmin = false;
    state.form.companyId = userInfo.companyId;
    state.form.companyName = userInfo.companyName;
    state.form.userType = 1;
  }

  state.title = type === 'add' ? '新增' : type ==='edit' ? '编辑' : type ==='pwd' ? '修改密码' : '查看' ;
  if(type === 'edit' || type === 'view') {
    if( type === 'view'){
      disabled.value = true;
    }

    state.form = JSON.parse(JSON.stringify(value))
    state.form.studentId = value.student.id
    state.form.studentName = value.student.name
    state.fileList = value.files.map(i => {
      return {
        name: i.fileName,
        path: i.filePath
      }
    })
    // state.form.studentName = value.company.name;
    console.log("ba",state.form)
  }
  if(type == 'pwd'){
    state.form.id = value.id
  }
  dialogVisible.value = true
}
const onSubmit = async () => {
  const valid = await superRef.value.validate();
  if(valid){
    if(state.title == '新增'){
      const {id,...data} = state.form
      const res = await addRecord(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }else if(state.title == '编辑'){
      const {...data} = state.form
      const res = await editRecord(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
      }else{
        ElMessage.warning(res.message)
      }
    }else{
      const {id,password} = state.form
      const data = {id,password}
      data.password = Base64.encode(data.password)
      const res = await resetPwd(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
      }else{
        ElMessage.warning(res.message)
      }
    }
  }
}

const handleClose = () => {
  state.form = {
    id: null,
    companyName: '',
    planName: '',
    studentId: '',
    level: '',
    period: '',
    actualPeriod: '',
    score: null,
    passed: 0,
    studentName: '',
    courseName: '',
    companyId: null

  }
  state.companyPageNum = 1;
  state.companyPageSize = 10;
  state.companyList = [];
  state.stuPageNum = 1;
  state.stuPageSize = 10;
  state.studentList = [];
  state.fileList = []
  superRef.value.clearValidate();
  superRef.value.resetFields()
  dialogVisible.value = false;
}

const selectValue = (val) => {
  state.studentList.forEach(item => {
    if(item.name === val){
      state.form.studentId = item.id
    }
  })
}

const selectCompany = (val) => {
  state.companyList.forEach(item => {
    if(item.name === val){
      state.form.companyId = item.id
    }
  })
}



const handleScrollStu = () => {
  console.log(' student',state.hasMoreStu);
  if(state.stuPageNum >= state.hasMoreStu) return
  state.stuPageNum++;
  loadMoreStuData()

}
const loadMoreStuData = async () => {
  const queryParams = {
    pageNum: state.stuPageNum,
    pageSize: state.stuPageSize,
  }
  const res = await getStudent(queryParams)
  if (res.code == 200) {
    state.hasMoreStu = res.data.totalPage
    const data = res.data
    state.studentList = state.studentList.concat(data.list)
  }else{
    ElMessage.warning(res.message)
  }
}

const handleScroll = () => {
  console.log(' Company',state.hasMoreItems);
  if(state.companyPageNum >= state.hasMoreItems) return
    state.companyPageNum++;
    loadMoreCompanyData()

}
const loadMoreCompanyData = async () => {
  const queryParams = {
    pageNum: state.companyPageNum,
    pageSize: state.companyPageSize,
  }
  const res = await getCompany(queryParams)
  if (res.code == 200) {
    state.hasMoreItems = res.data.totalPage
    const data = res.data
    state.companyList = state.companyList.concat(data.list)
  }else{
    ElMessage.warning(res.message)
  }
}
const handleAvatarSuccess = (response,uploadFile) => {
  if(response.code == 200){
    state.form.files = state.fileList.map(item => {
      return {
        fileName: item.response ? item.response?.data.originName: item.name,
        filePath: item.response ? item.response?.data.path: item.path
      }
    })
  }else{
    // state.fileList = []
    // state.form.files = []
    ElMessage({
      type: 'warning',
      message: response.message
    })
  }
}

const showTip =()=>{
  ElMessage({
    type: 'warning',
    message: '超出文件上传数量'
  });
}
const picSize = async (rawFile) => {
  if(rawFile.size / 1024 / 1024 > 5){
    ElMessage({
      type: 'warning',
      message: '文件大小不能超过5M'
    });
    return false
  }
};
const handleRemove = async (file, uploadFiles) => {
  state.form.files = state.fileList.map(item => {
    return {
      fileName: item.response ? item.response?.data.originName: item.name,
      filePath: item.response ? item.response?.data.path: item.path
    }
  })
  // let path = state.form.filePath;
  // await delPic({path: path}).then(res => {
  //   if(res.code == 200){
  //     // ElMessage({
  //     //   type: 'success',
  //     //   message: '文件已删除'
  //     // })
  //     state.form.fileName = ''
  //     state.form.filePath = ''
  //   }else{
  //     ElMessage({
  //       type: 'warning',
  //       message: res.message
  //     })
  //   }
  // }).catch(() => {
  //   state.form.fileName = ''
  //   state.form.filePath = ''
  // });
}


defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
